@@ -3,14 +3,21 @@ package org.gcube.portlets.user.td.columnwidget.client;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.gcube.portlets.user.td.columnwidget.client.progress.DeleteColumnProgressDialog;
 import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataProperties;
+import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.DeleteColumnSession;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
+import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
+import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
+import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableWhy;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
@@ -18,8 +25,10 @@ import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.core.client.Scheduler.ScheduledCommand;
+import com.google.gwt.event.shared.UmbrellaException;
 import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.web.bindery.event.shared.EventBus;
+import com.sencha.gxt.cell.core.client.ButtonCell.IconAlign;
 import com.sencha.gxt.core.client.IdentityValueProvider;
 import com.sencha.gxt.core.client.Style.SelectionMode;
 import com.sencha.gxt.core.client.dom.ScrollSupport.ScrollMode;
@@ -57,11 +66,12 @@ import com.sencha.gxt.widget.core.client.grid.Grid;
  *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
  * 
  */
-public class DeleteColumnPanel extends FramedPanel {
+public class DeleteColumnPanel extends FramedPanel implements
+		MonitorDialogListener {
 	protected String WIDTH = "640px";
 	protected String HEIGHT = "520px";
 	protected EventBus eventBus;
-	protected ChangeColumnTypeDialog parent;
+	protected DeleteColumnDialog parent;
 	protected TextField label = null;
 	protected TRId trId;
 	protected String columnName;
@@ -75,7 +85,7 @@ public class DeleteColumnPanel extends FramedPanel {
 	protected FieldLabel columnsSelectLabel;
 
 	protected DeleteColumnSession deleteColumnSession;
-	protected DeleteColumnProgressDialog deleteColumnProgressDialog;
+
 	private ListStore<ColumnData> store;
 
 	public DeleteColumnPanel(TRId trId, String columnName, EventBus eventBus) {
@@ -87,8 +97,8 @@ public class DeleteColumnPanel extends FramedPanel {
 		init();
 		build();
 	}
-	
-	public void init(){
+
+	public void init() {
 		setWidth(WIDTH);
 		setHeight(HEIGHT);
 		setHeaderVisible(false);
@@ -172,6 +182,10 @@ public class DeleteColumnPanel extends FramedPanel {
 
 		// Delete Button
 		delete = new TextButton("Delete");
+		delete.setIcon(ResourceBundle.INSTANCE.columnDelete());
+		delete.setIconAlign(IconAlign.RIGHT);
+		delete.setTitle("Delete Column");
+
 		SelectHandler deleteHandler = new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -218,19 +232,40 @@ public class DeleteColumnPanel extends FramedPanel {
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("load columns failure:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error retrieving columns",
-									"Error retrieving columns");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("load columns failure:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error retrieving columns",
+											"Error retrieving columns");
+								}
+							}
 						}
 						callback.onFailure(caught);
 
 					}
 
 					public void onSuccess(ArrayList<ColumnData> result) {
-						Log.trace("loaded " + result.size() + " ColumnData");
-						callback.onSuccess(new ListLoadResultBean<ColumnData>(
-								result));
+						try {
+							Log.debug("loaded " + result.size() + " ColumnData");
+							callback.onSuccess(new ListLoadResultBean<ColumnData>(
+									result));
+
+						} catch (UmbrellaException e) {
+							Log.debug("Umbrella exception "
+									+ e.getLocalizedMessage());
+						} catch (com.google.web.bindery.event.shared.UmbrellaException e) {
+							Log.debug("Umbrella exception "
+									+ e.getLocalizedMessage());
+						}
 
 					}
 
@@ -252,28 +287,90 @@ public class DeleteColumnPanel extends FramedPanel {
 		deleteColumnSession = new DeleteColumnSession(trId, columns);
 
 		TDGWTServiceAsync.INSTANCE.startDeleteColumn(deleteColumnSession,
-				new AsyncCallback<Void>() {
+				new AsyncCallback<String>() {
 
 					public void onFailure(Throwable caught) {
 						if (caught instanceof TDGWTSessionExpiredException) {
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.debug("Delete Column Error: "
-									+ caught.getLocalizedMessage());
-							UtilsGXT3
-									.alert("Delete Column Error ",
-											"Error in invocation of delete column operation!");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.debug("Delete Column Error: "
+											+ caught.getLocalizedMessage());
+									UtilsGXT3
+											.alert("Delete Column Error ",
+													"Error in invocation of delete column operation!");
+								}
+							}
 						}
 					}
 
-					public void onSuccess(Void result) {
-						deleteColumnProgressDialog = new DeleteColumnProgressDialog(
-								deleteColumnSession, eventBus);
+					public void onSuccess(String taskId) {
+						openMonitorDialog(taskId);
 					}
 
 				});
 
 	}
 
+	public void close() {
+		if (parent != null) {
+			parent.close();
+		}
+	}
+
+	// /
+	protected void openMonitorDialog(String taskId) {
+		MonitorDialog monitorDialog = new MonitorDialog(taskId, eventBus);
+		monitorDialog.addProgressDialogListener(this);
+		monitorDialog.show();
+	}
+
+	@Override
+	public void operationComplete(TRId trId) {
+		ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
+		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+				ChangeTableRequestType.DELETECOLUMN, trId, why);
+		eventBus.fireEvent(changeTableRequestEvent);
+		close();
+	}
+
+	@Override
+	public void operationFailed(Throwable caught, String reason, String details) {
+		UtilsGXT3.alert(reason, details);
+		close();
+
+	}
+
+	@Override
+	public void operationStopped(TRId trId, String reason, String details) {
+		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
+		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
+				ChangeTableRequestType.DELETECOLUMN, trId, why);
+		eventBus.fireEvent(changeTableRequestEvent);
+		close();
+
+	}
+
+	@Override
+	public void operationAborted() {
+		close();
+
+	}
+
+	@Override
+	public void operationPutInBackground() {
+		close();
+
+	}
+
 }
