@@ -15,6 +15,8 @@ import org.gcube.portlets.user.td.columnwidget.client.store.ShowOccurrencesTypeS
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.Constants;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.task.InvocationS;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
@@ -204,8 +206,7 @@ public class ReplaceBatchPanel extends FramedPanel implements
 				.create(ShowOccurrencesTypeProperties.class);
 		storeShowOccurrencesType = new ListStore<ShowOccurrencesTypeElement>(
 				propsShowOccurrencesType.id());
-		
-		
+
 		comboShowOccurrencesType = new ComboBox<ShowOccurrencesTypeElement>(
 				storeShowOccurrencesType, propsShowOccurrencesType.label());
 		Log.trace("ComboMeasureType created");
@@ -439,7 +440,8 @@ public class ReplaceBatchPanel extends FramedPanel implements
 		add(v);
 
 		if (curation) {
-			storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore.getShowOccurrencesType());
+			storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore
+					.getShowOccurrencesType());
 			if (connection != null) {
 				Log.debug("Selected connection: " + connection);
 				connectionField.setValue(connection.getLabel());
@@ -463,7 +465,8 @@ public class ReplaceBatchPanel extends FramedPanel implements
 						cViewData.getTargetTableColumnId());
 				retrieveConnectionForViewColumn(refCol);
 			} else {
-				storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore.getShowOccurrencesType());
+				storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore
+						.getShowOccurrencesType());
 				Log.debug("Not Is View Column");
 				connectionField.setVisible(false);
 				btnDisconnect.setVisible(false);
@@ -483,10 +486,22 @@ public class ReplaceBatchPanel extends FramedPanel implements
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("load column failure:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error retrieving column",
-									"Error retrieving column");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("load column failure:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error retrieving column",
+											"Error retrieving column");
+								}
+							}
 						}
 					}
 
@@ -510,10 +525,22 @@ public class ReplaceBatchPanel extends FramedPanel implements
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("load column failure:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error retrieving column",
-									"Error retrieving column");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("load column failure:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error retrieving column",
+											"Error retrieving column");
+								}
+							}
 						}
 					}
 
@@ -536,10 +563,22 @@ public class ReplaceBatchPanel extends FramedPanel implements
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("load column failure:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error retrieving column",
-									"Error retrieving column");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("load column failure:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error retrieving column",
+											"Error retrieving column");
+								}
+							}
 						}
 					}
 
@@ -615,10 +654,22 @@ public class ReplaceBatchPanel extends FramedPanel implements
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("load columns failure:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error retrieving columns",
-									"Error retrieving columns");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("load columns failure:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error retrieving columns",
+											"Error retrieving columns");
+								}
+							}
 						}
 						callback.onFailure(caught);
 					}
@@ -1014,10 +1065,23 @@ public class ReplaceBatchPanel extends FramedPanel implements
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("load column failure:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error retrieving connection",
-									"Error retrieving connection column");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("load column failure:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3
+											.alert("Error retrieving connection",
+													"Error retrieving connection column");
+								}
+							}
 						}
 					}
 
@@ -1041,10 +1105,23 @@ public class ReplaceBatchPanel extends FramedPanel implements
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.error("load column failure:"
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error retrieving connection",
-									"Error retrieving connection column");
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("load column failure:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3
+											.alert("Error retrieving connection",
+													"Error retrieving connection column");
+								}
+							}
 						}
 					}
 
